@@ -12,33 +12,23 @@ module Dotenv
         VARIABLE = /
           (\\)?         # is it escaped with a backslash?
           (\$)          # literal $
-          (?!\()        # shouldnt be followed by paranthesis
+          (?!\()        # shouldn't be followed by parenthesis
           \{?           # allow brace wrapping
           ([A-Z0-9_]+)? # optional alpha nums
           \}?           # closing brace
         /xi
 
-        def call(value, env, is_load)
-          combined_env = if is_load
-                           env.merge(ENV)
-                         else
-                           ENV.to_h.merge(env)
-                         end
+        def call(value, env)
           value.gsub(VARIABLE) do |variable|
             match = $LAST_MATCH_INFO
-            substitute(match, variable, combined_env)
-          end
-        end
 
-        private
-
-        def substitute(match, variable, env)
-          if match[1] == '\\'
-            variable[1..-1]
-          elsif match[3]
-            env.fetch(match[3], "")
-          else
-            variable
+            if match[1] == "\\"
+              variable[1..]
+            elsif match[3]
+              env[match[3]] || ENV[match[3]] || ""
+            else
+              variable
+            end
           end
         end
       end
